@@ -92,7 +92,10 @@ _service_endpoints_template = {
     'serverlessrepo': '{proto}://{host}:4631',
     'appconfig': '{proto}://{host}:4632',
     'ce': '{proto}://{host}:4633',
-    'mediaconvert': '{proto}://{host}:4634'
+    'mediaconvert': '{proto}://{host}:4634',
+    'resourcegroupstaggingapi':'{proto}://{host}:4635',
+    'resource-groups': '{proto}://{host}:4636',
+    'efs': '{proto}://{host}:4637'
 }
 
 # TODO remove service port mapping above entirely
